// Miscellaneous Operators: https://docs.mongodb.com/manual/reference/operator/aggregation/rand/#mongodb-expression-exp.-rand
import { computeValue } from "../../../core";
import { assert, isNil, isObject, isString } from "../../../util";
/**
 * Adds, updates, or removes a specified field in a document.
 *
 * @param {*} obj The target object for this expression
 * @param {*} expr The right-hand side of the operator
 * @param {Options} options Options to use for operation
 */
export const $getField = (obj, expr, options) => {
    const args = computeValue(obj, expr, null, options);
    const [field, input] = isObject(args)
        ? [args.field, args.input || obj]
        : [args, obj];
    if (isNil(input))
        return null;
    assert(isObject(input), "$getField expression 'input' must evaluate to an object");
    assert(isString(field), "$getField expression 'field' must evaluate to a string");
    return input[field];
};
